@@ -1,9 +1,14 @@
 'use strict';
 
-var regex = require('regex-not');
-var Cache = require('fragment-cache');
-var utils = module.exports;
-var cache = utils.cache = new Cache();
+const regex = require('regex-not');
+const Cache = require('fragment-cache');
+
+/**
+ * Utils
+ */
+
+const utils = module.exports;
+const cache = utils.cache = new Cache();
 
 /**
  * Cast `val` to an array
@@ -22,13 +27,13 @@ utils.arrayify = function(val) {
  */
 
 utils.memoize = function(type, pattern, options, fn) {
-  var key = utils.createKey(type + pattern, options);
+  const key = utils.createKey(type + pattern, options);
 
   if (cache.has(type, key)) {
     return cache.get(type, key);
   }
 
-  var val = fn(pattern, options);
+  const val = fn(pattern, options);
   if (options && options.cache === false) {
     return val;
   }
@@ -44,11 +49,11 @@ utils.memoize = function(type, pattern, options, fn) {
  */
 
 utils.createKey = function(pattern, options) {
-  var key = pattern;
+  let key = pattern;
   if (typeof options === 'undefined') {
     return key;
   }
-  for (var prop in options) {
+  for (const prop in options) {
     key += ';' + prop + '=' + String(options[prop]);
   }
   return key;
@@ -59,6 +64,6 @@ utils.createKey = function(pattern, options) {
  */
 
 utils.createRegex = function(str) {
-  var opts = {contains: true, strictClose: false};
+  const opts = {contains: true, strictClose: false};
   return regex(str, opts);
 };
