@@ -5,7 +5,8 @@ var match = require('./support/match');
 var extglob = require('..');
 
 /**
- * These tests were converted directly from bash 4.3 and 4.4 unit tests.
+ * Most of these tests were converted directly from
+ * bash 4.3 and 4.4 unit tests.
  */
 
 describe('extglobs', function() {
@@ -13,7 +14,7 @@ describe('extglobs', function() {
     assert.equal(typeof extglob, 'function');
   });
 
-  it.skip('failing unit test from bash', function() {
+  it.skip('failing unit tests from bash', function() {
     match(['moo.cow'], '!(*.*).!(*.*)', ['moo.cow']);
     match(['foo.js.js'], '*.!(js)*', ['foo.js.js']);
   });
@@ -38,6 +39,12 @@ describe('extglobs', function() {
     match(['c/z/v'], 'c/z/v', ['c/z/v']);
   });
 
+  it('should work with file extensions', function() {
+    match(['.md', 'a.js', 'a.md', 'b.md', 'c.md'], '@(a|b).md', ['a.md', 'b.md']);
+    match(['.md', 'a.js', 'a.md', 'aa.md', 'ab.md', 'b.md', 'bb.md', 'c.md'], '+(a|b).md', ['a.md', 'aa.md', 'ab.md', 'b.md', 'bb.md']);
+    match(['.md', 'a.js', 'a.md', 'aa.md', 'ab.md', 'b.md', 'bb.md', 'c.md'], '*(a|b).md', ['.md', 'a.md', 'aa.md', 'ab.md', 'b.md', 'bb.md']);
+  });
+
   it('should support star (`*`) extglobs', function() {
     match(['cz', 'abz', 'az'], 'a*(z)', ['az']);
     match(['cz', 'abz', 'az'], 'a**(z)', ['az', 'abz']);
@@ -47,6 +54,7 @@ describe('extglobs', function() {
   });
 
   it('should support negation (`!`) extglobs', function() {
+    match(['moo.cow'], '!(!(moo)).!(!(cow))', ['moo.cow']);
     match(['c/z/v', 'c/a/v'], 'c/!(z)/v', ['c/a/v']);
     match(['c/z/v', 'c/a/v'], 'c/!(z)/v', ['c/a/v']);
     match(['cz', 'abz', 'az'], 'a!(z)', ['abz']);
@@ -66,10 +74,23 @@ describe('extglobs', function() {
     match(f1, '!((?:b/a))', ['a/a', 'a/b', 'a/c', 'b/b', 'b/c']);
     match(f1, '!(b/(a))', ['a/a', 'a/b', 'a/c', 'b/b', 'b/c']);
 
+    match(['b', 'b  ', 'b ', 'c  '], '@(!(a) {1,2})*', ['b  ', 'b ', 'c  ']);
+    match(['b', 'b ', 'bb', 'ccc'], '@(!(a) {1,2})*', ['b ']);
+    match(['b', 'a ', 'b ', 'bb', 'ccc'], '@(!(a){1,2} )*', ['b ']);
+
     var f2 = ['a', 'b', 'aa', 'ab', 'bb', 'ac', 'aaa', 'aab', 'abb', 'ccc'];
     match(f2, '!(a)', ['aa', 'aaa', 'aab', 'ab', 'abb', 'ac', 'b', 'bb', 'ccc']);
+    match(f2, '!(a*)', ['b', 'bb', 'ccc']);
+    match(f2, '!(*a*)', ['b', 'bb', 'ccc']);
+    match(f2, '!(*a)', ['aab', 'ab', 'abb', 'ac', 'b', 'bb', 'ccc']);
     match(f2, '!(a)*', ['b', 'bb', 'ccc']);
+    match(f2, '!(*a)*', ['b', 'bb', 'ccc']);
     match(f2, 'a!(b)*', ['a', 'aa', 'aaa', 'aab', 'ac']);
+    match(['aajs', 'bajs', 'aamd', 'abmd'], 'a!(a)md', ['abmd']);
+    match(['aajs', 'bajs', 'aamd', 'abmd'], 'a!(.)md', ['aamd', 'abmd']);
+    match(['a.js', 'a.md', 'b.md', 'c.md'], '!(a|b).md', ['c.md']);
+    match(['a.js', 'a.md', 'b.md', 'c.md'], '!(a|c).md', ['b.md']);
+    match(['a.js', 'a.md', 'b.md', 'b.js', 'c.md'], '!(a|c).@(md|js)', ['b.md', 'b.js']);
   });
 
   it('should support plus (`+`) extglobs', function() {
